@@ -58,7 +58,6 @@ import cylc.flags
 from cylc.graphnode import GraphNodeParser, GraphNodeError
 from cylc.print_tree import print_tree
 from cylc.subprocctx import SubFuncContext
-from cylc.subprocpool import get_func
 from cylc.suite_srv_files_mgr import SuiteSrvFilesManager
 from cylc.taskdef import TaskDef, TaskDefError
 from cylc.task_id import TaskID
@@ -155,7 +154,6 @@ class SuiteConfig(object):
             self.xtrigger_mgr = XtriggerManager(self.suite)
         else:
             self.xtrigger_mgr = xtrigger_mgr
-        self.xtriggers = {}
         self.suite_polling_tasks = {}
         self._last_graph_raw_id = None
         self._last_graph_raw_edges = []
@@ -363,18 +361,20 @@ class SuiteConfig(object):
             set_utc_mode(self.cfg['cylc']['UTC mode'])
 
         # Initial point from suite definition (or CLI override above).
-        icp = self.cfg['scheduling']['initial cycle point']
-        if icp is None:
+        orig_icp = self.cfg['scheduling']['initial cycle point']
+        if orig_icp is None:
             raise SuiteConfigError(
                 "This suite requires an initial cycle point.")
-        if icp == "now":
+        if orig_icp == "now":
             icp = get_current_time_string()
         else:
             try:
                 my_now = get_current_time_string()
-                icp = ingest_time(icp, my_now)
+                icp = ingest_time(orig_icp, my_now)
             except ValueError as exc:
                 raise SuiteConfigError(str(exc))
+        if orig_icp != icp:
+            self.options.icp = icp
         self.initial_point = get_point(icp).standardise()
         self.cfg['scheduling']['initial cycle point'] = str(self.initial_point)
         if getattr(self.options, 'startcp', None) is not None:
@@ -1647,7 +1647,7 @@ class SuiteConfig(object):
             # Record custom message outputs.
             for item in self.cfg['runtime'][name]['outputs'].items():
                 if item not in taskdef.outputs:
-                    taskdef.outputs.append(item)
+                    taskdef.outputs.add(item)
                     # Check for obsolete task message offsets.
                     if BCOMPAT_MSG_RE_C6.match(item[1]):
                         raise SuiteConfigError(
@@ -1739,11 +1739,26 @@ class SuiteConfig(object):
             dependency = Dependency(expr_list, set(triggers.values()), suicide)
             self.taskdefs[right].add_dependency(dependency, seq)
 
-        # Record xtrigger labels for each task name.
-        if right not in self.xtriggers:
-            self.xtriggers[right] = xtrig_labels
-        else:
-            self.xtriggers[right] = self.xtriggers[right].union(xtrig_labels)
+        for label in xtrig_labels:
+            try:
+                xtrig = self.cfg['scheduling']['xtriggers'][label]
+            except KeyError:
+                if label == 'wall_clock':
+                    # Allow "@wall_clock" in the graph as an undeclared
+                    # zero-offset clock xtrigger.
+                    xtrig = SubFuncContext(
+                        'wall_clock', 'wall_clock', [], {})
+                else:
+                    raise SuiteConfigError(
+                        "ERROR, undefined xtrigger label: %s" % label)
+            if (xtrig.func_name == 'wall_clock' and
+                    self.cfg['scheduling']['cycling mode'] == (
+                        INTEGER_CYCLING_TYPE)):
+                raise SuiteConfigError(
+                    "ERROR: clock triggers are not compatible with integer "
+                    "cycling.\n %s = %s" % (label, xtrig.get_signature()))
+            self.xtrigger_mgr.add_trig(label, xtrig, self.fdir)
+            self.taskdefs[right].add_xtrig_label(label, seq)
 
     def get_actual_first_point(self, start_point):
         """Get actual first cycle point for the suite
@@ -2084,51 +2099,6 @@ class SuiteConfig(object):
             self._proc_triggers(
                 parser.triggers, parser.original, seq, task_triggers)
 
-        xtcfg = self.cfg['scheduling']['xtriggers']
-        # Taskdefs just know xtrigger labels.
-        for task_name, xt_labels in self.xtriggers.items():
-            for label in xt_labels:
-                try:
-                    xtrig = xtcfg[label]
-                except KeyError:
-                    if label == 'wall_clock':
-                        # Allow predefined zero-offset wall clock xtrigger.
-                        xtrig = SubFuncContext(
-                            'wall_clock', 'wall_clock', [], {})
-                    else:
-                        raise SuiteConfigError(
-                            "ERROR, undefined xtrigger label: %s" % label)
-                if xtrig.func_name.startswith('wall_clock'):
-                    self.xtrigger_mgr.add_clock(label, xtrig)
-                    # Replace existing xclock if the new offset is larger.
-                    try:
-                        offset = get_interval(xtrig.func_kwargs['offset'])
-                    except KeyError:
-                        offset = 0
-                    old_label = self.taskdefs[task_name].xclock_label
-                    if old_label is None:
-                        self.taskdefs[task_name].xclock_label = label
-                    else:
-                        old_xtrig = self.xtrigger_mgr.clockx_map[old_label]
-                        old_offset = get_interval(
-                            old_xtrig.func_kwargs['offset'])
-                        if offset > old_offset:
-                            self.taskdefs[task_name].xclock_label = label
-                else:
-                    try:
-                        if not callable(get_func(xtrig.func_name, self.fdir)):
-                            raise SuiteConfigError(
-                                "ERROR, "
-                                "xtrigger function not callable: %s" %
-                                xtrig.func_name)
-                    except (ImportError, AttributeError):
-                        raise SuiteConfigError(
-                            "ERROR, "
-                            "xtrigger function not found: %s" %
-                            xtrig.func_name)
-                    self.xtrigger_mgr.add_trig(label, xtrig)
-                    self.taskdefs[task_name].xtrig_labels.add(label)
-
         # Detect use of xtrigger names with '@' prefix (creates a task).
         overlap = set(self.taskdefs.keys()).intersection(
             self.cfg['scheduling']['xtriggers'].keys())
