@@ -429,7 +429,7 @@ To start a new run, stop the old one first with one or more of these:
                 name = os.path.basename(os.path.dirname(arg))
         return name, path
 
-    def register(self, reg=None, source=None, redirect=False):
+    def register(self, reg=None, source=None, redirect=False, rundir=None):
         """Register a suite, or renew its registration.
 
         Create suite service directory and symlink to suite source location.
@@ -468,7 +468,28 @@ To start a new run, stop the old one first with one or more of these:
 
         # Create service dir if necessary.
         srv_d = self.get_suite_srv_dir(reg)
-        mkdir_p(srv_d)
+        if rundir is None:
+            mkdir_p(srv_d)
+        else:
+            suite_run_d, srv_d_name = os.path.split(srv_d)
+            alt_suite_run_d = os.path.join(rundir, reg)
+            alt_srv_d = os.path.join(rundir, reg, srv_d_name)
+            mkdir_p(alt_srv_d)
+            mkdir_p(os.path.dirname(suite_run_d))
+            if os.path.islink(suite_run_d) and not os.path.exists(suite_run_d):
+                # Remove a bad symlink.
+                os.unlink(suite_run_d)
+            if not os.path.exists(suite_run_d):
+                os.symlink(alt_suite_run_d, suite_run_d)
+            elif not os.path.islink(suite_run_d):
+                raise SuiteServiceFileError(
+                    "Run directory '%s' already exists." % suite_run_d)
+            elif alt_suite_run_d != os.readlink(suite_run_d):
+                target = os.readlink(suite_run_d)
+                raise SuiteServiceFileError(
+                    "Symlink '%s' already points to %s." % (
+                        suite_run_d, target))
+            # (else already the right symlink)
 
         # See if suite already has a source or not
         try:
