@@ -696,6 +696,18 @@ class TaskPool(object):
         self.max_num_active_cycle_points = (
             self.config.get_max_num_active_cycle_points())
 
+        # find any old tasks that have been removed from the suite
+        old_task_name_list = self.task_name_list
+        self.task_name_list = self.config.get_task_name_list()
+        for name in old_task_name_list:
+            if name not in self.task_name_list:
+                self.orphans.append(name)
+        for name in self.task_name_list:
+            if name in self.orphans:
+                self.orphans.remove(name)
+        # adjust the new suite config to handle the orphans
+        self.config.adopt_orphans(self.orphans)
+
         # reassign live tasks from the old queues to the new.
         # self.queues[queue][id_] = task
         self.assign_queues()
@@ -709,18 +721,6 @@ class TaskPool(object):
                 new_queues[key][id_] = itask
         self.queues = new_queues
 
-        # find any old tasks that have been removed from the suite
-        old_task_name_list = self.task_name_list
-        self.task_name_list = self.config.get_task_name_list()
-        for name in old_task_name_list:
-            if name not in self.task_name_list:
-                self.orphans.append(name)
-        for name in self.task_name_list:
-            if name in self.orphans:
-                self.orphans.remove(name)
-        # adjust the new suite config to handle the orphans
-        self.config.adopt_orphans(self.orphans)
-
     def reload_taskdefs(self):
         """Reload task definitions."""
         LOG.info("Reloading task definitions.")
@@ -1263,16 +1263,13 @@ class TaskPool(object):
                 else:
                     extras['External trigger "%s"' % trig] = 'NOT satisfied'
             for label, satisfied in itask.state.xtriggers.items():
+                extra = 'xtrigger "%s = %s"' % (
+                    label, self.xtrigger_mgr.get_xtrig_ctx(
+                        itask, label).get_signature())
                 if satisfied:
-                    extras['xtrigger "%s"' % label] = 'satisfied'
+                    extras[extra] = 'satisfied'
                 else:
-                    extras['xtrigger "%s"' % label] = 'NOT satisfied'
-            if itask.state.xclock is not None:
-                label, satisfied = itask.state.xclock
-                if satisfied:
-                    extras['xclock "%s"' % label] = 'satisfied'
-                else:
-                    extras['xclock "%s"' % label] = 'NOT satisfied'
+                    extras[extra] = 'NOT satisfied'
 
             outputs = []
             for _, msg, is_completed in itask.state.outputs.get_all():
@@ -1289,8 +1286,6 @@ class TaskPool(object):
         itasks = self.get_tasks()
         self.xtrigger_mgr.collate(itasks)
         for itask in itasks:
-            if itask.state.xclock is not None:
-                self.xtrigger_mgr.satisfy_xclock(itask)
             if itask.state.xtriggers:
                 self.xtrigger_mgr.satisfy_xtriggers(itask, self.proc_pool)
 
